@@ -289,7 +289,7 @@ def get_client_ip(request):
 	        ip = request.META.get('REMOTE_ADDR')
 	    return ip
 	except: return "unknown"
-def __get_client_ip__(request): # depricated.
+def get_client_ip(request): # depricated.
 	return get_client_ip(request)
 	
 
